@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (c) 1995-1999 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-2003 Joey Hess (joey@kitenet.net)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -15,11 +15,12 @@
 #include <signal.h>
 #include "slang.h"
 #include <stdio.h>
-#include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <libintl.h>
+#define _(String) gettext (String)
 
 /* equals 1 if the screen is set up in slang mode */
 int screen_is_setup=0;
@@ -130,21 +131,8 @@ RETSIGTYPE Sigwinch_Handler (int sig) {
  */
 void Screen_Init () {
   static int SLkp_init_ran;
-  int fd;
-  char *tty_ptr;
   
   if (screen_is_setup == 0) {
-    /*
-     * Make sure that we have the real tty open as stdin.
-     * You see, if a rc file is passed to pdmenu on stdin, then
-     * after the rc file is read, there is no longer stdin available
-     * for programs pdmenu launches to use.
-     */
-    tty_ptr = ttyname(0);
-    fd = open(tty_ptr, O_RDWR);
-    dup2(fd, 0);
-    close(fd);
-
     SLsig_block_signals(); /* Block signals while initializing. */
 
     SLtt_get_terminfo();
@@ -156,7 +144,7 @@ void Screen_Init () {
     if (SLkp_init_ran != 1) {
       if (SLkp_init() == -1) {
 	SLsig_unblock_signals();
-	Error(KP_INIT_ERROR);
+	Error(_("Unable to initialize key mappings."));
       }
       SLkp_init_ran=1;
     }
@@ -166,7 +154,7 @@ void Screen_Init () {
     SLtt_Use_Ansi_Colors=Use_Color;
 
     SLsignal(SIGWINCH,Sigwinch_Handler);
-
+    
     SLsig_unblock_signals();
 
     screen_is_setup=1;
@@ -202,5 +190,5 @@ void SetScreensize () {
   SLtt_get_screen_size();
 
   if ((SLtt_Screen_Rows < MIN_ROWS) || (SLtt_Screen_Cols < MIN_COLS))
-    Error(SCREEN_TOOSMALL);
+    Error(_("Error: The screen is too small."));
 }
